@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 
 """
-SimpleGUICS2Pygame package (December 16, 2013)
+SimpleGUICS2Pygame package (May 25, 2014)
 
 It is primarily a standard Python_ (2 **and** 3) module
 reimplementing the SimpleGUI particular module of CodeSkulptor_
@@ -17,37 +17,42 @@ Module simpleplot require matplotlib_ .
 
 `Online HTML documentation`_ on Read The Docs.
 
+| Sources and installers on Bitbucket: https://bitbucket.org/OPiMedia/simpleguics2pygame
+| and on PyPI: https://pypi.python.org/pypi/SimpleGUICS2Pygame .
+
 Piece of SimpleGUICS2Pygame.
 https://bitbucket.org/OPiMedia/simpleguics2pygame
 
-GPLv3 --- Copyright (C) 2013 Olivier Pirson
+GPLv3 --- Copyright (C) 2013, 2014 Olivier Pirson
 http://www.opimedia.be/
 
 .. _CodeSkulptor: http://www.codeskulptor.org/
+.. _matplotlib: http://matplotlib.org/
 .. _`Online HTML documentation`: https://readthedocs.org/docs/simpleguics2pygame/en/latest/
 .. _Pygame: http://www.pygame.org/
 .. _Python: http://www.python.org/
 .. _`Unofficial Windows Binaries`: http://www.lfd.uci.edu/~gohlke/pythonlibs/#pygame
 
-v.01.04.00 --- December 16, 2013
-v.01.03.00 --- December 13, 2013
-v.01.02.00 --- November 8, 2013
-v.01.01.00 --- November 1st, 2013
-v.01.00.02 --- October 31, 2013
-v.01.00.01 --- October 9, 2013
-v.01.00.00 --- July 13, 2013
-v.00.92.00 --- June 27, 2013
-v.00.91.00 --- June 23, 2013
-v.00.90.10 --- June 19, 2013
-v.00.90.00 --- June 13, 2013
-Started on May 21, 2013
+* v.01.05.00 --- May 25, 2014
+* v.01.04.00 --- December 16, 2013
+* v.01.03.00 --- December 13, 2013
+* v.01.02.00 --- November 8, 2013
+* v.01.01.00 --- November 1st, 2013
+* v.01.00.02 --- October 31, 2013
+* v.01.00.01 --- October 9, 2013
+* v.01.00.00 --- July 13, 2013
+* v.00.92.00 --- June 27, 2013
+* v.00.91.00 --- June 23, 2013
+* v.00.90.10 --- June 19, 2013
+* v.00.90.00 --- June 13, 2013
+* Started on May 21, 2013
 
 `Complete changelog`_
 
 .. _`Complete changelog`: https://simpleguics2pygame.readthedocs.org/en/latest/ChangeLog.html
 """
 
-_VERSION = '01.04.00'
+_VERSION = '01.05.00'
 """
 Version of SimpleGUICS2Pygame package.
 """
@@ -61,7 +66,7 @@ Website of the project.
 #
 # GPLv3
 # ------
-# Copyright (C) 2013 Olivier Pirson
+# Copyright (C) 2013, 2014 Olivier Pirson
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
