@@ -2,7 +2,7 @@
 # -*- coding: latin-1 -*-
 
 """
-Example of codeskulptor_lib_loader.Loader use. (December 13, 2013)
+Example of simplegui_lib_loader.Loader use. (May 25, 2014)
 
 Documentation:
 https://simpleguics2pygame.readthedocs.org/en/latest/simplegui_lib_loader.html
@@ -10,14 +10,14 @@ https://simpleguics2pygame.readthedocs.org/en/latest/simplegui_lib_loader.html
 Piece of SimpleGUICS2Pygame.
 https://bitbucket.org/OPiMedia/simpleguics2pygame
 
-GPLv3 --- Copyright (C) 2013 Olivier Pirson
+GPLv3 --- Copyright (C) 2013, 2014 Olivier Pirson
 http://www.opimedia.be/
 """
 
 try:
     import simplegui
 
-    from user27_rSvHGawbvoYISaV import Loader
+    from user33_PJRhxILEqeTIZKf import Loader
 except ImportError:
     import SimpleGUICS2Pygame.simpleguics2pygame as simplegui
 
@@ -26,7 +26,7 @@ except ImportError:
     simplegui.Frame._hide_status = True
 
 
-WIDTH = 300
+WIDTH = 400
 HEIGHT = 200
 
 
@@ -60,7 +60,7 @@ def init():
     Init function called after image loaded.
     """
     # Init your stuff...
-    frame.add_button('Quit', quit)
+    frame.add_button('Quit', quit_prog)
 
     music = loader.get_sound('soundtrack')  # get a sound by its name
     music.play()
@@ -80,7 +80,7 @@ def init():
     frame.set_draw_handler(draw)
 
 
-def quit():
+def quit_prog():
     """
     Stop sounds and frame
     """
