@@ -6,7 +6,7 @@ script/cs2both.py
 
 Script that change a CodeSkulptor program
 to run in CodeSkulptor *and* Python SimpleGUICS2Pygame.
-(October 29, 2013)
+(April 21, 2014)
 
 A file codeskulptor_program.py is copied
 to codeskulptor_program.py.bak before changing.
@@ -18,14 +18,14 @@ Changes made :
   by
   try:
       import simplegui
-  except:
+  except ImportError:
       import SimpleGUICS2Pygame.simpleguics2pygame as simplegui
 - *Try* to check if a timer is started *after* the start frame.
 
 Piece of SimpleGUICS2Pygame.
 https://bitbucket.org/OPiMedia/simpleguics2pygame
 
-GPLv3 --- Copyright (C) 2013 Olivier Pirson
+GPLv3 --- Copyright (C) 2013, 2014 Olivier Pirson
 http://www.opimedia.be/
 """
 
@@ -38,36 +38,12 @@ import re
 import sys
 
 
-def help():
-    print("""cs2both.py codeskulptor_program.py
-
-Make automatically little changes in codeskulptor_program.py
-to run in CodeSkulptor *and* Python SimpleGUICS2Pygame.
-
-The file codeskulptor_program.py is copied
-to codeskulptor_program.py.bak before changing.
-
-Changes made :
-- Add shebang '#!/usr/bin/env python'.
-- Add '# -*- coding: latin-1 -*-'.
-- Replace import simplegui
-  by
-  try:
-      import simplegui
-  except:
-      import SimpleGUICS2Pygame.simpleguics2pygame as simplegui
-- *Try* to check if a timer is started *after* the start frame.
-""")
-
-    exit(1)
-
-
-########
-# Main #
-########
-if __name__ == '__main__':
+def main():
+    """
+    Main function.
+    """
     if (len(sys.argv) != 2) or (sys.argv[1][0] == '-'):
-        help()
+        help_and_exit()
 
     filename = sys.argv[1]
 
@@ -87,11 +63,11 @@ if __name__ == '__main__':
         exit(1)
 
     # Read
-    f = open(filename)
+    infile = open(filename)
 
-    lines = [line.rstrip() for line in f]
+    lines = [line.rstrip() for line in infile]
 
-    f.close()
+    infile.close()
 
     # Check
     if len(lines) < 2:
@@ -100,8 +76,8 @@ if __name__ == '__main__':
         exit()
 
     add_shebang = lines[0][:2]
-    add_coding = (not re.match('#\w*-\*- coding: \W+ -\*-$', lines[0])
-                  and not re.match('#\w*-\*- coding: \W+ -\*-$', lines[1]))
+    add_coding = (not re.match(r'#\w*-\*- coding: \W+ -\*-$', lines[0])
+                  and not re.match(r'#\w*-\*- coding: \W+ -\*-$', lines[1]))
 
     change_import = False
     already_change_import = False
@@ -119,15 +95,15 @@ if __name__ == '__main__':
 
     for line in lines:
         if (not already_change_import
-                and re.search('^\w*import SimpleGUICS2Pygame', line)):
+                and re.search(r'^\w*import SimpleGUICS2Pygame', line)):
             already_change_import = True
 
     if not already_change_import:
         for i, line in enumerate(lines):
-            r = re.match('(\w)*import simplegui$', line)
-            if r:
+            match = re.match(r'(\w)*import simplegui$', line)
+            if match:
                 change_import = True
-                indent = (r.group(1) if r.group(1)
+                indent = (match.group(1) if match.group(1)
                           else '')
                 lines[i] = '\n' + indent + ('\n' + indent).join(
                     ("# Automatically modified by 'cs2both.py'",
@@ -135,7 +111,7 @@ if __name__ == '__main__':
                      '# https://bitbucket.org/OPiMedia/simpleguics2pygame',
                      'try:',
                      '    import simplegui',
-                     'except:',
+                     'except ImportError:',
                      '    import SimpleGUICS2Pygame.simpleguics2pygame as simplegui')) + '\n'
 
     # Write
@@ -143,17 +119,17 @@ if __name__ == '__main__':
         os.rename(filename, filename + '.bak')
         print("File copied to {}.bak'".format(filename))
 
-        f = (open(filename, mode='w', encoding='latin_1', newline='\n')
-             if sys.version_info[0] >= 3
-             else open(filename, mode='w'))
+        outfile = (open(filename, mode='w', encoding='latin_1', newline='\n')
+                   if sys.version_info[0] >= 3
+                   else open(filename, mode='w'))
 
         if add_shebang:
             print('Add shebang.')
-            print('#!/usr/bin/env python', file=f)
+            print('#!/usr/bin/env python', file=outfile)
 
         if add_coding:
             print('Add coding latin-1.')
-            print('# -*- coding: latin-1 -*-', file=f)
+            print('# -*- coding: latin-1 -*-', file=outfile)
 
         if change_import:
             print('Change import simplegui.')
@@ -161,18 +137,53 @@ if __name__ == '__main__':
         if end_blank_line:
             print('End blank line deleted.')
 
-        print('\n'.join(lines), file=f)
+        print('\n'.join(lines), file=outfile)
 
-        f.close()
+        outfile.close()
     else:
         print('Nothing changed.')
 
     while lines:
         line = lines.pop()
-        if re.search('^\w*f(rame)?\.start\(\)', line):  # f.start()
-                                                        #   or frame.start()
+        if re.search(r'^\w*f(rame)?\.start\(\)', line):  # f.start()
+                                                         #   or frame.start()
             break
-        elif re.search('^\w*[^#]+\.start\(\)', line):   # other .start()
+        elif re.search(r'^\w*[^#]+\.start\(\)', line):   # other .start()
             print('Warning: Maybe a timer is started *after* the start frame.')
 
             break
+
+
+def help_and_exit():
+    """
+    Print help message on error output
+    and exit.
+    """
+    print("""cs2both.py codeskulptor_program.py
+
+Make automatically little changes in codeskulptor_program.py
+to run in CodeSkulptor *and* Python SimpleGUICS2Pygame.
+
+The file codeskulptor_program.py is copied
+to codeskulptor_program.py.bak before changing.
+
+Changes made :
+- Add shebang '#!/usr/bin/env python'.
+- Add '# -*- coding: latin-1 -*-'.
+- Replace import simplegui
+  by
+  try:
+      import simplegui
+  except ImportError:
+      import SimpleGUICS2Pygame.simpleguics2pygame as simplegui
+- *Try* to check if a timer is started *after* the start frame.
+""", file=sys.stderr)
+
+    exit(1)
+
+
+########
+# Main #
+########
+if __name__ == '__main__':
+    main()
